module mdy_fifo_1_1(
    clk_in      ,
    clk_out     ,
    rst_n       ,
    data_in     ,
    data_in_vld ,
    b_rdy       ,

    data_out    ,
    data_out_vld
    );

    parameter      DATA_W =         16;

    input               clk_in      ;
    input               rst_n       ;
    input               clk_out     ;
    input               b_rdy       ;
    input               data_in_vld ;
    input [DATA_W-1:0]  data_in     ;  

    output[DATA_W-1:0]  data_out    ;
    output              data_out_vld;

    reg   [DATA_W-1:0]  data_out    ;
    reg                 data_out_vld;

    wire [5:0]          wrusedw     ;
    reg                 wrreq       ;
    wire[DATA_W-1:0]    q           ;
    wire                rdreq       ;


    
    always  @(*)begin
        if(wrusedw>=61)
            wrreq = 0;
        else
            wrreq = data_in_vld;
    end


    fifo_ahead#(.DATA_W(DATA_W),.DEPT_W(64)) u_fifo(
	    .aclr   (~rst_n    ),
        .data   (data_in   ),
	    .rdclk  (clk_out   ),
	    .rdreq  (rdreq     ),
	    .wrclk  (clk_in    ),
	    .wrreq  (wrreq     ),
        .q      (q         ),
        .rdempty(rdempty   ),
        .wrusedw(wrusedw   ) 
	);


    assign rdreq = b_rdy==1 && rdempty==0;  




    always  @(posedge clk_out or negedge rst_n)begin
        if(rst_n==1'b0)begin
            data_out <= 0;
        end
        else begin
            data_out <= q;
        end
    end

    always  @(posedge clk_out or negedge rst_n)begin
        if(rst_n==1'b0)begin
            data_out_vld <= 0;
        end
        else begin
            data_out_vld <= rdreq;
        end
    end
    

endmodule


