module mdy_fifo_1_2(
    clk_in      ,
    clk_out     ,
    rst_n       ,

    b_rdy       ,
    data_in     ,
    data_in_vld ,

    data_out_vld,
    data_out    
    );

    parameter      DOUT_W =         8;
    parameter      DIN_W =         16;

    input                clk_in        ; 
    input                clk_out       ; 
    input                rst_n         ; 

    input                b_rdy         ; 
    input [DIN_W-1:0]    data_in       ; 
    input                data_in_vld   ; 
    output               data_out_vld  ;
    output[DOUT_W-1:0]   data_out      ;  

    reg                  data_out_vld  ;
    reg   [DOUT_W-1:0]   data_out      ; 

    reg                  wrreq         ;
    wire                 rdreq         ;
    wire [DIN_W -1:0]    q             ;
    wire [ 5:0]          wrusedw       ; 

    reg [ 0:0]           cnt0          ;
    wire                 add_cnt0      ;
    wire                 end_cnt0      ;


    always  @(*)begin
        if(wrusedw>=61)
            wrreq = 0;
        else
            wrreq = data_in_vld;
    end



    fifo_ahead#(.DATA_W(DIN_W),.DEPT_W(64)) u_fifo(
	    .aclr    (~rst_n    ) ,
        .data    (data_in   ) ,
	    .wrreq   (wrreq     ) ,
	    .wrclk   (clk_in    ) ,
	    .rdclk   (clk_out   ) ,
	    .rdreq   (rdreq     ) ,
        .q       (q         ) ,
        .rdempty (rdempty   ) ,
        .wrusedw (wrusedw   )   
	);


    

always @(posedge clk_out or negedge rst_n) begin 
    if (rst_n==0) begin
        cnt0 <= 0; 
    end
    else if(add_cnt0) begin
        if(end_cnt0)
            cnt0 <= 0; 
        else
            cnt0 <= cnt0+1 ;
   end
end
assign add_cnt0 = b_rdy && rdempty==0;
assign end_cnt0 = add_cnt0  && cnt0 == 2 -1 ;


assign rdreq = end_cnt0 ; 

always  @(posedge clk_out or negedge rst_n)begin
    if(rst_n==1'b0)begin
        data_out <= 0;
    end
    else begin
        data_out <= q[DIN_W-1-DOUT_W*cnt0 -:DOUT_W];
    end
end

always  @(posedge clk_out or negedge rst_n)begin
    if(rst_n==1'b0)begin
        data_out_vld <= 0;
    end
    else begin
        data_out_vld <= add_cnt0;
    end
end



endmodule

