module mdy_fifo_1_6 (
    clk         ,
    rst_n       ,
    din         ,
    b_rdy       ,
    din_vld     ,
    din_sop     ,
    din_eop     ,

    dout        ,
    dout_vld    ,
    dout_sop    ,
    dout_eop       
    );

    parameter      DIN_W  =          8;
    parameter      DOUT_W =          8;
    input               clk         ;
    input               rst_n       ;
    input[DIN_W-1:0]    din         ; 
    input               b_rdy       ; 
    input               din_vld     ; 
    input               din_sop     ; 
    input               din_eop     ; 

    output[DOUT_W-1:0]  dout        ;
    output              dout_vld    ; 
    output              dout_sop    ; 
    output              dout_eop    ; 

    reg   [DOUT_W-1:0]  dout        ;
    reg                 dout_vld    ; 
    reg                 dout_sop    ; 
    reg                 dout_eop    ; 

    wire                wrreq       ;
    wire [DIN_W+2-1:0]  data        ;
    wire [DIN_W+2-1:0]  q           ;
    wire                rdempty     ;
    wire                rdreq       ;


assign wrreq = din_vld              ; 
assign data  = {din_sop,din_eop,din};



fifo_ahead#(.DATA_W(DIN_W+2),.DEPT_W(256)) u_fifo(
	.aclr    (~rst_n    ) ,
    .data    (data      ) ,
	.rdclk   (clk       ) ,
	.rdreq   (rdreq     ) ,
	.wrclk   (clk       ) ,
	.wrreq   (wrreq     ) ,
    .q       (q         ) ,
    .rdempty (rdempty   )    
	);

assign rdreq = rdempty==0 && b_rdy==1;

always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        dout_sop <= 0;
        dout_eop <= 0;
        dout_vld <= 0;
        dout     <= 0;
    end
    else begin
        dout_sop <= q[DOUT_W+2-1];
        dout_eop <= q[DOUT_W+2-2];
        dout_vld <= rdreq ;
        dout     <= q[DOUT_W-1:0];
    end
end





endmodule

