module mdy_fifo_1_8 (
    clk         ,
    rst_n       ,
    din         ,
    b_rdy       ,
    din_vld     ,
    din_sop     ,
    din_eop     ,

    dout        ,
    dout_vld    ,
    dout_sop    ,
    dout_eop       
    );

    parameter      DIN_W  =         32;
    parameter      DOUT_W =          8;
    input               clk         ;
    input               rst_n       ;
    input[DIN_W-1:0]    din         ; 
    input               b_rdy       ; 
    input               din_vld     ; 
    input               din_sop     ; 
    input               din_eop     ; 

    output[DOUT_W-1:0]  dout        ;
    output              dout_vld    ; 
    output              dout_sop    ; 
    output              dout_eop    ; 

    reg   [DOUT_W-1:0]  dout        ;
    reg                 dout_vld    ; 
    reg                 dout_sop    ; 
    reg                 dout_eop    ; 

    wire                wrreq       ;
    wire [17       :0]  data        ;
    wire [17       :0]  q           ;
    wire                rdempty     ;
    wire                rdreq       ;
    reg [ 1:0]          cnt0        ;
    wire                add_cnt0    ;
    wire                end_cnt0    ;

    assign wrreq =  din_vld ;
    assign data  = {din_sop,din_eop,din };

fifo_ahead#(.DATA_W(34),.DEPT_W(256)) u_fifo(
	.aclr    (~rst_n    ) ,
    .data    (data      ) ,
	.rdclk   (clk       ) ,
	.rdreq   (rdreq     ) ,
	.wrclk   (clk       ) ,
	.wrreq   (wrreq     ) ,
    .q       (q         ) ,
    .rdempty (rdempty   )  
	);




always @(posedge clk or negedge rst_n) begin 
    if (rst_n==0) begin
        cnt0 <= 0; 
    end
    else if(add_cnt0) begin
        if(end_cnt0)
            cnt0 <= 0; 
        else
            cnt0 <= cnt0+1 ;
   end
end
assign add_cnt0 = rdempty==0 && b_rdy==1;
assign end_cnt0 = add_cnt0  && cnt0 == 4-1 ;

assign rdreq = end_cnt0 ;


always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        dout_vld  <= 0;
        dout_sop  <= 0;
        dout_eop  <= 0;
        dout      <= 0;
    end
    else begin
        dout_vld  <= add_cnt0 ;
        dout_sop  <= q[33] && add_cnt0 && cnt0==1-1;
        dout_eop  <= q[32] && end_cnt0 ;
        dout      <= q[31-cnt0*8 -:8]  ;
    end
end




endmodule

