module mdy_fifo_1_9 (
    clk         ,
    rst_n       ,
    din         ,
    b_rdy       ,
    din_vld     ,
    din_sop     ,
    din_eop     ,

    dout        ,
    dout_vld    ,
    dout_sop    ,
    dout_eop    ,
    dout_mty        
    );

    parameter      DIN_W  =          8;
    parameter      DOUT_W =         16;
    input               clk         ;
    input               rst_n       ;
    input[DIN_W-1:0]    din         ; 
    input               b_rdy       ; 
    input               din_vld     ; 
    input               din_sop     ; 
    input               din_eop     ; 

    output[DOUT_W-1:0]  dout        ;
    output              dout_vld    ; 
    output              dout_sop    ; 
    output              dout_eop    ; 
    output              dout_mty    ; 

    reg   [DOUT_W-1:0]  dout        ;
    reg                 dout_vld    ; 
    reg                 dout_sop    ; 
    reg                 dout_eop    ; 
    reg                 dout_mty    ; 
    reg [ 0:0]          cnt0        ;
    wire                add_cnt0    ;
    wire                end_cnt0    ;
    reg [15:0]          fifo_din    ;
    reg                 fifo_sop    ;
    reg                 fifo_eop    ;
    reg                 fifo_mty    ;
    wire[18:0]          data        ;
    reg                 wrreq       ;
    wire                rdreq       ;
    wire[18:0]          q           ;
    wire                rdempty     ;





always @(posedge clk or negedge rst_n) begin 
    if (rst_n==0) begin
        cnt0 <= 0; 
    end
    else if(add_cnt0) begin
        if(end_cnt0)
            cnt0 <= 0; 
        else
            cnt0 <= cnt0+1 ;
   end
end
assign add_cnt0 = din_vld ;
assign end_cnt0 = add_cnt0  && (cnt0 == 2-1 || din_eop);

always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        fifo_din <= 0;
    end
    else if(add_cnt0)begin
        fifo_din[15-8*cnt0 -:8] <= din;
    end
    /*
    else if(add_cnt0 && cnt0==1-1) begin
        fifo_din[15:8] <= din;
    end
    else if(add_cnt0 && cnt0==2-1)begin
        fifo_din[ 7:0] <= din;
    end
    */
end

always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        fifo_sop <= 0;
    end
    else if(din_vld && din_sop)begin
        fifo_sop <= 1;
    end
    else if(wrreq)begin
        fifo_sop <= 0;
    end
end

always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        fifo_eop <= 0;
    end
    else begin
        fifo_eop <= din_eop;
    end
end

always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        fifo_mty <= 0;
    end
    else if(din_eop && add_cnt0 && cnt0==1-1) begin
        fifo_mty <= 1;
    end
    else begin
        fifo_mty <= 0;
    end
end

assign data = {fifo_sop,fifo_eop,fifo_mty,fifo_din};

always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        wrreq <= 0;
    end
    else begin
        wrreq <= end_cnt0;
    end
end




fifo_ahead#(.DATA_W(19),.DEPT_W(256)) u_fifo(
	.aclr    (~rst_n    ) ,
    .data    (data      ) ,
	.rdclk   (clk       ) ,
	.rdreq   (rdreq     ) ,
	.wrclk   (clk       ) ,
	.wrreq   (wrreq     ) ,
    .q       (q         ) ,
    .rdempty (rdempty   )    
	);

    assign rdreq = rdempty==0 && b_rdy==1;

    always  @(posedge clk or negedge rst_n)begin
        if(rst_n==1'b0)begin
            dout     <= 0;
            dout_vld <= 0;
            dout_sop <= 0;
            dout_eop <= 0;
            dout_mty <= 0;
        end
        else begin
            dout     <= q[15:0] ;
            dout_vld <= rdreq   ;
            dout_sop <= q[18]   ;
            dout_eop <= q[17]   ;
            dout_mty <= q[16]   ;
        end
    end





endmodule

